@@ -41,6 +41,7 @@ import gc
 import urllib
 import sys
 import tempfile
+import service
 
 class win_attach(object):
 	def __init__(self, model, id, parent=None):
@@ -48,8 +49,9 @@ class win_attach(object):
 				gettext.textdomain())
 		self.win = self.glade.get_widget('win_attach')
 		self.win.set_icon(common.TINYERP_ICON)
-		if parent:
-			self.win.set_transient_for(parent)
+		if not parent:
+			parent = service.LocalService('gui.main').window
+		self.win.set_transient_for(parent)
 		self.parent = parent
 		self.ressource = (model, id)
 
