@@ -2,7 +2,7 @@
 #
 # Copyright (c) 2004-2006 TINY SPRL. (http://tiny.be) All Rights Reserved.
 #
-# $Id: many2many.py 5421 2007-01-25 08:35:14Z ced $
+# $Id: many2many.py 7119 2007-08-17 16:23:36Z ced $
 #
 # WARNING: This program as such is intended to be used by professional
 # programmers who take the whole responsability of assessing all potential
@@ -29,7 +29,6 @@
 
 import gobject
 import gtk
-from gtk import glade
 
 import gettext
 
@@ -49,25 +48,41 @@ class many2many(interface.widget_interface):
 	def __init__(self, window, parent, model, attrs={}):
 		interface.widget_interface.__init__(self, window, parent, model, attrs)
 
-		self.win_gl = glade.XML(common.terp_path("terp.glade"),"widget_many2many", gettext.textdomain())
-		self.win_gl.signal_connect('on_m2m_but_add_pressed', self._sig_add )
-		self.win_gl.signal_connect('on_m2m_but_remove_pressed', self._sig_remove )
+		self.widget = gtk.VBox(homogeneous=False, spacing=1)
 
-		vbox = gtk.VBox(homogeneous=False, spacing=1)
-		vbox.pack_start(self.win_gl.get_widget('widget_many2many'))
-
-		# if attrs.get('view_data_tree'): ...
-		self.screen = Screen(attrs['relation'], view_type=['tree'])
-
-		self.win_gl.get_widget('scrolledwindow7').add_with_viewport(self.screen.widget)
-		self.widget = vbox
-
-		self.wid_text = self.win_gl.get_widget('ent_many2many')
+		hb = gtk.HBox(homogeneous=False, spacing=3)
+		self.wid_text = gtk.Entry()
+		self.wid_text.set_property('width_chars', 13)
 		self.wid_text.connect('activate', self._sig_activate)
 		self.wid_text.connect('button_press_event', self._menu_open)
+		hb.pack_start(self.wid_text, expand=True, fill=True)
+
+		hb.pack_start(gtk.VSeparator(), padding=2, expand=False, fill=False)
+
+		self.wid_but_add = gtk.Button(stock='gtk-add')
+		self.wid_but_add.set_relief(gtk.RELIEF_HALF)
+		self.wid_but_add.set_focus_on_click(True)
+		self.wid_but_add.connect('clicked', self._sig_add)
+		hb.pack_start(self.wid_but_add, padding=3, expand=False, fill=False)
+
+		self.wid_but_remove = gtk.Button(stock='gtk-remove')
+		self.wid_but_remove.set_relief(gtk.RELIEF_HALF)
+		self.wid_but_remove.set_focus_on_click(True)
+		self.wid_but_remove.connect('clicked', self._sig_remove)
+		hb.pack_start(self.wid_but_remove, expand=False, fill=False)
+
+		self.widget.pack_start(hb, expand=False, fill=False)
+		self.widget.pack_start(gtk.HSeparator(), expand=False, fill=True)
+
+		scroll = gtk.ScrolledWindow()
+		scroll.set_policy(gtk.POLICY_AUTOMATIC, gtk.POLICY_AUTOMATIC)
+		scroll.set_placement(gtk.CORNER_TOP_LEFT)
+		scroll.set_shadow_type(gtk.SHADOW_NONE)
+
+		self.screen = Screen(attrs['relation'], view_type=['tree'])
+		scroll.add_with_viewport(self.screen.widget)
+		self.widget.pack_start(scroll, expand=True, fill=True)
 
-		self.wid_but_add = self.win_gl.get_widget('m2m_but_add')
-		self.wid_but_remove = self.win_gl.get_widget('m2m_but_remove')
 		self.old = None
 
 	def destroy(self):
@@ -75,22 +90,18 @@ class many2many(interface.widget_interface):
 		self.widget.destroy()
 		del self.widget
 
-	def _menu_sig_default_set(self):
-		self.set_value(self._view.modelfield)
-		return super(many2many, self)._menu_sig_default_set()
-
 	def _menu_sig_default(self, obj):
 		res = rpc.session.rpc_exec_auth('/object', 'execute', self.attrs['model'], 'default_get', [self.attrs['name']])
 		self.value = res.get(self.attrs['name'], False)
 
 	def _sig_add(self, *args):
-		domain = self._view.modelfield.domain_get()
-		context = self._view.modelfield.context_get()
+		domain = self._view.modelfield.domain_get(self._view.model)
+		context = self._view.modelfield.context_get(self._view.model)
 
 		ids = rpc.session.rpc_exec_auth('/object', 'execute', self.attrs['relation'], 'name_search', self.wid_text.get_text(), domain, 'ilike', context)
 		ids = map(lambda x: x[0], ids)
 		if len(ids)<>1:
-			win = win_search(self.attrs['relation'], sel_multi=True, ids=ids)
+			win = win_search(self.attrs['relation'], sel_multi=True, ids=ids, context=context, domain=domain, parent=self._window)
 			ids = win.go()
 
 		self.screen.load(ids)
@@ -103,18 +114,18 @@ class many2many(interface.widget_interface):
 
 	def _sig_activate(self, *args):
 		self._sig_add()
-	
+
 	def _readonly_set(self, ro):
 		self.wid_text.set_editable(not ro)
 		self.wid_text.set_sensitive(not ro)
 		self.wid_but_remove.set_sensitive(not ro)
 		self.wid_but_add.set_sensitive(not ro)
 
-	def display(self, model_field):
-		super(many2many, self).display(model_field)
+	def display(self, model, model_field):
+		super(many2many, self).display(model, model_field)
 		ids = []
 		if model_field:
-			ids = model_field.get_client()
+			ids = model_field.get_client(model)
 		if ids<>self.old:
 			self.screen.clear()
 			self.screen.load(ids)
@@ -122,6 +133,6 @@ class many2many(interface.widget_interface):
 		self.screen.display()
 		return True
 
-	def set_value(self, model_field):
-		model_field.set_client([x.id for x in self.screen.models.models])
+	def set_value(self, model, model_field):
+		model_field.set_client(model, [x.id for x in self.screen.models.models])
 
