@@ -2,7 +2,7 @@
 #
 # Copyright (c) 2004-2006 TINY SPRL. (http://tiny.be) All Rights Reserved.
 #
-# $Id$
+# $Id: parser.py 8235 2008-01-29 16:27:34Z ced $
 #
 # WARNING: This program as such is intended to be used by professional
 # programmers who take the whole responsability of assessing all potential
@@ -387,6 +387,7 @@ class parser_form(widget.view.interface.parser_interface):
 		if not id:
 			common.message(_('You need to save resource before adding translations'))
 			return False
+		id = self.screen.current_model.save(reload=False)
 		uid = rpc.session.uid
 
 		lang_ids = rpc.session.rpc_exec_auth('/object', 'execute', 'res.lang', 'search', [('translatable','=','1')])
@@ -533,6 +534,7 @@ class parser_form(widget.view.interface.parser_interface):
 				self.window.present()
 				win.destroy()
 				return
+		self.screen.current_model.reload()
 		self.window.present()
 		win.destroy()
 		return True
