@@ -2,7 +2,7 @@
 #
 # Copyright (c) 2004-2006 TINY SPRL. (http://tiny.be) All Rights Reserved.
 #
-# $Id: selection.py 5421 2007-01-25 08:35:14Z ced $
+# $Id: selection.py 7761 2007-10-19 14:05:46Z ced $
 #
 # WARNING: This program as such is intended to be used by professional
 # programmers who take the whole responsability of assessing all potential
@@ -31,29 +31,26 @@ import common
 import interface
 import gtk
 import gobject
-from gtk import glade
 
 import gettext
 
 
-# Can be improved !!!
-
 class selection(interface.widget_interface):
 	def __init__(self, window, parent, model, attrs={}):
 		interface.widget_interface.__init__(self, window, parent, model, attrs)
 
-		win_gl = glade.XML(common.terp_path("terp.glade"),"widget_combobox", gettext.textdomain())
-		self.widget = win_gl.get_widget('widget_combobox')
-
-		#self.widget = gtk.combo_box_entry_new_text()
-		self.widget.child.connect('changed', self.sig_changed)
-		self.widget.child.set_editable(False)
-		self.widget.child.connect('button_press_event', self._menu_open)
-		self.widget.child.connect('key_press_event', self.sig_key_pressed)
-		#self.widget.set_has_frame(False)
+		self.widget = gtk.HBox(spacing=3)
+		self.entry = gtk.ComboBoxEntry()
+		self.entry.child.connect('changed', self.sig_changed)
+		self.entry.child.set_editable(False)
+		self.entry.child.connect('button_press_event', self._menu_open)
+		self.entry.child.connect('key_press_event', self.sig_key_pressed)
+		self.entry.set_size_request(int(attrs.get('size', -1)), -1)
+		self.widget.pack_start(self.entry, expand=True, fill=True)
 
 		self.ok = True
 		self._selection={}
+		self.key_catalog = {}
 		self.set_popdown(attrs.get('selection',[]))
 		self.last_key = (None, 0)
 
@@ -72,40 +69,40 @@ class selection(interface.widget_interface):
 			if l:
 				key = l[0].lower()
 				self.key_catalog.setdefault(key,[]).append(i)
-		self.widget.set_model(model)
-		self.widget.set_text_column(0)
+		self.entry.set_model(model)
+		self.entry.set_text_column(0)
 		return lst
 
 	def _readonly_set(self, value):
 		interface.widget_interface._readonly_set(self, value)
-		self.widget.set_sensitive(not value)
+		self.entry.set_sensitive(not value)
 
 	def value_get(self):
-		res = self.widget.child.get_text()
+		res = self.entry.child.get_text()
 		return self._selection.get(res, False)
 
-	def set_value(self, model_field):
-		model_field.set_client(self.value_get())
+	def set_value(self, model, model_field):
+		model_field.set_client(model, self.value_get())
 
 	def _menu_sig_default_set(self):
-		self.set_value(self._view.modelfield)
+		self.set_value(self._view.model, self._view.modelfield)
 		super(selection, self)._menu_sig_default_set()
 
-	def display(self, model_field):
+	def display(self, model, model_field):
 		self.ok = False
 		if not model_field:
-			self.widget.child.set_text('')
+			self.entry.child.set_text('')
 			self.ok = True
 			return False
-		super(selection, self).display(model_field)
-		value = model_field.get()
+		super(selection, self).display(model, model_field)
+		value = model_field.get(model)
 		if not value:
-			self.widget.child.set_text('')
+			self.entry.child.set_text('')
 		else:
 			found = False
 			for long_text, sel_value in self._selection.items():
 				if sel_value == value:
-					self.widget.child.set_text(long_text)
+					self.entry.child.set_text(long_text)
 					found = True
 					break
 		self.ok = True
@@ -125,7 +122,7 @@ class selection(interface.widget_interface):
 			self.last_key = [ key, 1 ]
 		if not self.key_catalog.has_key(key):
 			return
-		self.widget.set_active_iter(self.key_catalog[key][self.last_key[1] % len(self.key_catalog[key])])
+		self.entry.set_active_iter(self.key_catalog[key][self.last_key[1] % len(self.key_catalog[key])])
 
 	def _color_widget(self):
-		return self.widget.child
+		return self.entry.child
