@@ -2,7 +2,7 @@
 #
 # Copyright (c) 2004-2006 TINY SPRL. (http://tiny.be) All Rights Reserved.
 #
-# $Id: textbox.py 4751 2006-12-01 14:50:46Z ced $
+# $Id: textbox.py 6664 2007-07-10 17:24:34Z ced $
 #
 # WARNING: This program as such is intended to be used by professional
 # programmers who take the whole responsability of assessing all potential
@@ -28,28 +28,26 @@
 ##############################################################################
 
 import gtk
-from gtk import glade
 
 import interface
 
 class textbox(interface.widget_interface):
 	def __init__(self, window, parent, model, attrs={}):
 		interface.widget_interface.__init__(self, window, parent, model, attrs)
+
+		self.widget = gtk.ScrolledWindow()
+		self.widget.set_policy(gtk.POLICY_AUTOMATIC, gtk.POLICY_AUTOMATIC)
+		self.widget.set_shadow_type(gtk.SHADOW_NONE)
+		self.widget.set_size_request(-1, 80)
+
 		self.tv = gtk.TextView()
 		self.tv.set_wrap_mode(gtk.WRAP_WORD)
-		sw = gtk.ScrolledWindow()
-		sw.set_policy(gtk.POLICY_AUTOMATIC, gtk.POLICY_ALWAYS)
-		sw.set_shadow_type(gtk.SHADOW_NONE)
-		sw.set_size_request(-1, 80)
-		sw.add(self.tv)
-		self.widget=sw
 		self.tv.connect('button_press_event', self._menu_open)
 		self.tv.set_accepts_tab(False)
-#		if self.attrs['readonly']:
-#			self.tv.set_editable(False)
-#			self.widget.set_sensitive(False)
 		self.tv.connect('focus-out-event', lambda x,y: self._focus_out())
-		sw.show_all()
+		self.widget.add(self.tv)
+
+		self.widget.show_all()
 
 	def _readonly_set(self, value):
 		interface.widget_interface._readonly_set(self, value)
@@ -59,16 +57,16 @@ class textbox(interface.widget_interface):
 	def _color_widget(self):
 		return self.tv
 
-	def set_value(self, model_field):
+	def set_value(self, model, model_field):
 		buffer = self.tv.get_buffer()
 		iter_start = buffer.get_start_iter()
 		iter_end = buffer.get_end_iter()
 		current_text = buffer.get_text(iter_start,iter_end,False)
-		model_field.set_client(current_text or False)
+		model_field.set_client(model, current_text or False)
 
-	def display(self, model_field):
-		super(textbox, self).display(model_field)
-		value = model_field and model_field.get()
+	def display(self, model, model_field):
+		super(textbox, self).display(model, model_field)
+		value = model_field and model_field.get(model)
 		if not value:
 			value=''
 		buffer = self.tv.get_buffer()
