@@ -2,7 +2,7 @@
 #
 # Copyright (c) 2004-2006 TINY SPRL. (http://tiny.be) All Rights Reserved.
 #
-# $Id$
+# $Id: parser.py 8220 2008-01-21 16:44:25Z ced $
 #
 # WARNING: This program as such is intended to be used by professional
 # programmers who take the whole responsability of assessing all potential
@@ -51,6 +51,8 @@ import service
 def send_keys(renderer, editable, position, treeview):
 	editable.connect('key_press_event', treeview.on_keypressed)
 	editable.editing_done_id = editable.connect('editing_done', treeview.on_editing_done)
+	if isinstance(editable, gtk.ComboBoxEntry):
+		editable.connect('changed', treeview.on_editing_done)
 
 def sort_model(column, treeview):
 	model = treeview.get_model()
@@ -469,10 +471,13 @@ class Selection(Char):
 
 	def value_from_text(self, model, text):
 		selection = model[self.field_name].attrs['selection']
+		res = False
 		for val, txt in selection:
-			if txt == text:
-				return val
-		return False
+			if txt[:len(text)].lower() == text.lower():
+				if len(txt) == len(text):
+					return val
+				res = val
+		return res
 
 CELLTYPES = {
 	'char': Char,
